Šajā lapā

zabbix_sender

ZABBIX_SENDER(1)            Vispārīgo komandu rokasgrāmata           ZABBIX_SENDER(1)

NOSAUKUMS
       zabbix_sender - Zabbix sūtītāja utilīta

KOPSAVILKUMS
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

APRAKSTS
       zabbix_sender ir komandrindas utilīta uzraudzības datu nosūtīšanai uz
       Zabbix serveri vai starpniekserveri. Zabbix serverī jāizveido vienums ar
       tipu Zabbix trapper un atbilstošo atslēgu. Ņemiet vērā, ka ienākošās
       vērtības tiks pieņemtas tikai no hostiem, kas šī vienuma laukā Allowed
       hosts ir norādīti kā atļautie.

OPCIJAS
       -c, --config config-file
              Izmanto config-file. Zabbix sender nolasa servera informāciju no
              agentd konfigurācijas faila. Pēc noklusējuma Zabbix sender
              nelasa nevienu konfigurācijas failu. Tiek atbalstīti tikai
              parametri Hostname, ServerActive, SourceIP, TLSConnect,
              TLSCAFile, TLSCRLFile, TLSServerCertIssuer,
              TLSServerCertSubject, TLSCertFile, TLSKeyFile, TLSPSKIdentity un
              TLSPSKFile. Hostname, kas definēts, izmantojot parametru
              HostnameItem, netiks izmantots; šādā gadījumā hosts jānorāda
              komandrindā (skatiet opciju -s). Datu nosūtīšanai tiek izmantotas
              visas adreses, kas definētas aģenta ServerActive konfigurācijas
              parametrā. Ja pakešu datu nosūtīšana uz vienu adresi neizdodas,
              nākamās paketes uz šo adresi netiek nosūtītas.

       -z, --zabbix-server server
              Zabbix servera resursdatora nosaukums vai IP adrese. Ja hosts tiek
              uzraudzīts, izmantojot starpniekserveri, tā vietā jāizmanto
              starpniekservera resursdatora nosaukums vai IP adrese. Izmantojot
              kopā ar --config, šī opcija aizstāj ServerActive parametra
              ierakstus, kas norādīti agentd konfigurācijas failā.

       -p, --port port
              Norāda Zabbix servera trapper porta numuru. Noklusējuma vērtība ir
              10051. Izmantojot kopā ar --config, šī opcija aizstāj
              ServerActive parametra porta ierakstus, kas norādīti agentd
              konfigurācijas failā.

       -I, --source-address IP-address
              Norāda avota IP adresi. Izmantojot kopā ar --config, šī opcija
              aizstāj aģenta konfigurācijas failā norādīto SourceIP parametru.

       -t, --timeout seconds
              Norāda taimautu. Derīgais diapazons: 1-300 sekundes (noklusējums:
              60).

       -s, --host host
              Norāda tā hosta nosaukumu, kuram pieder vienums (kā reģistrēts
              Zabbix lietotāja saskarnē). Hosta IP adrese un DNS nosaukums
              nedarbosies. Izmantojot kopā ar --config, šī opcija aizstāj
              aģenta konfigurācijas failā norādīto Hostname parametru.

       -k, --key key
              Norāda vienuma atslēgu, uz kuru nosūtīt vērtību.

       -o, --value value
              Norāda vienuma vērtību.

       -i, --input-file input-file
              Ielādē vērtības no ievades faila. Norādiet - kā <input-file>, lai
              nolasītu vērtības no standarta ievades. Katrā faila rindā ir ar
              atstarpēm atdalīti elementi: <hostname> <key> <value>. Katra
              vērtība jānorāda atsevišķā rindā. Katrā rindā jābūt 3 ar atstarpēm
              atdalītiem ierakstiem: <hostname> <key> <value>, kur "hostname" ir
              uzraudzītā hosta nosaukums, kas reģistrēts Zabbix lietotāja
              saskarnē, "key" ir mērķa vienuma atslēga un "value" ir nosūtāmā
              vērtība. Norādiet - kā <hostname>, lai izmantotu hosta nosaukumu
              no aģenta konfigurācijas faila vai argumenta --host.

              Ievades faila rindas piemērs:

               "Linux DB3" db.connections 43

              Vērtības tipam jābūt pareizi iestatītam Zabbix lietotāja
              saskarnes vienuma konfigurācijā. Zabbix sender vienā savienojumā
              nosūtīs līdz 250 vērtībām. Ievades faila saturam jābūt UTF-8
              kodējumā. Visas ievades faila vērtības tiek nosūtītas secīgi no
              augšas uz leju. Ieraksti jāformatē, ievērojot šādus noteikumus:

                     • Tiek atbalstīti ieraksti ar pēdiņām un bez tām.

                     • Pēdiņu rakstzīme ir dubultpēdiņa.

                     • Ieraksti, kuros ir atstarpes, jāiekļauj pēdiņās.

                     • Dubultpēdiņas un slīpsvītras rakstzīmes ierakstā, kas
                       iekļauts pēdiņās, jāekranē ar slīpsvītru.

                     • Ierakstos bez pēdiņām ekrānošana netiek atbalstīta.

                     • Rindas padeves ekvivalentsekvences (\n) tiek atbalstītas
                       virknēs, kas iekļautas pēdiņās.

                     • Rindas padeves ekvivalentsekvences tiek noņemtas no
                       ieraksta beigām.

       -T, --with-timestamps
              Šo opciju var izmantot tikai kopā ar opciju --input-file.

              Katrā ievades faila rindā jābūt 4 ar atstarpēm atdalītiem
              ierakstiem: <hostname> <key> <timestamp> <value>. Laikspiedogs
              jānorāda Unix laikspiedoga formātā. Ja uz mērķa vienumu attiecas
              trigeri, visiem laikspiedogiem jābūt augošā secībā; pretējā
              gadījumā notikumu aprēķins nebūs pareizs.

              Ievades faila rindas piemērs:

               "Linux DB3" db.connections 1429533600 43

              Papildinformāciju skatiet opcijas --input-file aprakstā.

              Ja hostam, kas atrodas uzturēšanas periodā ar tipu “no data”,
              tiek nosūtīta vērtība ar laikspiedogu, šī vērtība tiks atmesta;
              tomēr vērtību ar laikspiedogu var nosūtīt arī beigušamies
              uzturēšanas periodam, un tā tiks pieņemta.

       -N, --with-ns
              Šo opciju var izmantot tikai kopā ar opciju --with-timestamps.

              Katrā ievades faila rindā jābūt 5 ar atstarpēm atdalītiem
              ierakstiem: <hostname> <key> <timestamp> <ns> <value>.

              Ievades faila rindas piemērs:

               "Linux DB3" db.connections 1429533600 7402561 43

              Papildinformāciju skatiet opcijas --input-file aprakstā.

       -r, --real-time
              Nosūta vērtības pa vienai, tiklīdz tās tiek saņemtas. To var
              izmantot, nolasot datus no standarta ievades.

       --tls-connect value
              Kā izveidot savienojumu ar serveri vai starpniekserveri. Vērtības:

                   unencrypted
                               izveidot savienojumu bez šifrēšanas (noklusējums)

                   psk         izveidot savienojumu, izmantojot TLS un iepriekš
                               koplietotu atslēgu

                   cert        izveidot savienojumu, izmantojot TLS un
                               sertifikātu

       --tls-ca-file CA-file
              Pilns ceļš uz failu, kurā ir augstākā līmeņa CA sertifikāts(-i)
              partnera sertifikāta pārbaudei.

       --tls-crl-file CRL-file
              Pilns ceļš uz failu, kurā ir atsauktie sertifikāti.

       --tls-server-cert-issuer cert-issuer
              Atļautais servera sertifikāta izdevējs.

       --tls-server-cert-subject cert-subject
              Atļautais servera sertifikāta subjekts.

       --tls-cert-file cert-file
              Pilns ceļš uz failu, kurā ir sertifikāts vai sertifikātu ķēde.

       --tls-key-file key-file
              Pilns ceļš uz failu, kurā ir privātā atslēga.

       --tls-psk-identity PSK-identity
              PSK-identity virkne.

       --tls-psk-file PSK-file
              Pilns ceļš uz failu, kurā ir iepriekš koplietotā atslēga.

       --tls-cipher13 cipher-string
              OpenSSL 1.1.1 vai jaunākas versijas šifru virkne TLS 1.3.
              Aizstāj noklusējuma šifru komplekta atlases kritērijus. Šī opcija
              nav pieejama, ja OpenSSL versija ir vecāka par 1.1.1.

       --tls-cipher cipher-string
              GnuTLS prioritātes virkne (TLS 1.2 un jaunākām versijām) vai
              OpenSSL šifru virkne (tikai TLS 1.2). Aizstāj noklusējuma šifru
              komplekta atlases kritērijus.

       -v, --verbose
              Detalizētais režīms; -vv nodrošina vēl vairāk informācijas.

       -h, --help
              Parāda šo palīdzību un iziet.

       -V, --version
              Izvada informāciju par versiju un iziet.

IZIETES STATUSS
       Izejas statuss ir 0, ja vērtības tika nosūtītas un serveris tās visas
       veiksmīgi apstrādāja. Ja dati tika nosūtīti, bet vismaz vienas vērtības
       apstrāde neizdevās, izejas statuss ir 2. Ja datu nosūtīšana neizdevās,
       izejas statuss ir 1.

PIEMĒRI
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Nosūta 342.45 kā uzraudzītā hosta mysql.queries vienuma vērtību.
              Izmanto uzraudzīto hostu un Zabbix serveri, kas definēti aģenta
              konfigurācijas failā.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Nosūta 342.45 kā Monitored Host hosta mysql.queries vienuma
              vērtību, izmantojot Zabbix serveri, kas definēts aģenta
              konfigurācijas failā.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Nosūta vērtības no faila data_values.txt uz Zabbix serveri ar IP
              adresi 192.168.1.113. Hosta nosaukumi un atslēgas ir definēti
              failā.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Nosūta vērtību ar laikspiedogu no komandrindas uz Zabbix serveri,
              kas norādīts aģenta konfigurācijas failā. Defise ievades datos
              norāda, ka hosta nosaukums jāizmanto no tā paša konfigurācijas
              faila.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              No komandrindas nosūta tukšu vienuma vērtību uz Zabbix serveri ar
              IP adresi 192.168.1.113 un 10000. portu. Tukšas vērtības jānorāda
              ar tukšām dubultpēdiņām.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Nosūta 342.45 kā Monitored Host hosta mysql.queries vienuma
              vērtību serverim ar IP adresi 192.168.1.113, izmantojot TLS ar
              sertifikātu.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Nosūta 342.45 kā Monitored Host hosta mysql.queries vienuma
              vērtību serverim ar IP adresi 192.168.1.113, izmantojot TLS ar
              iepriekš koplietotu atslēgu (PSK).

SKATIET ARĪ
       Dokumentācija

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)